==> dangerzone.0.7.buildkit.zip: src/dangerzone/entities/EntityTransient.java <==
package dangerzone.entities;
import dangerzone.DangerZone;
import dangerzone.Player;
import dangerzone.Utils;
import dangerzone.World;

/*
 * This code is copyright Richard H. Clark, TheyCallMeDanger, OreSpawn, 2015-2020.
 * You may use this code for reference for modding the DangerZone game program,
 * and are perfectly welcome to cut'n'paste portions for your mod as well.
 * DO NOT USE THIS CODE FOR ANY PURPOSE OTHER THAN MODDING FOR THE DANGERZONE GAME.
 * DO NOT REDISTRIBUTE THIS CODE. 
 * 
 * This copyright remains in effect until January 1st, 2021. 
 * At that time, this code becomes public domain.
 * 
 * WARNING: There are bugs. Big bugs. Little bugs. Every size in-between bugs.
 * This code is NOT suitable for use in anything other than this particular game. 
 * NO GUARANTEES of any sort are given, either express or implied, and Richard H. Clark, 
 * TheyCallMeDanger, OreSpawn are not responsible for any damages, direct, indirect, or otherwise. 
 * You should have made backups. It's your own fault for not making them.
 * 
 * NO ATTEMPT AT SECURITY IS MADE. This code is USE AT YOUR OWN RISK.
 * Regardless of what you may think, the reality is, that the moment you 
 * connected your computer to the Internet, Uncle Sam, among many others, hacked it.
 * DO NOT KEEP VALUABLE INFORMATION ON INTERNET-CONNECTED COMPUTERS.
 * Or your phone...
 * 
 */
public class EntityTransient extends EntityLiving {
	
	public boolean daytimecheck = true;
	public boolean nighttimecheck = false;

	public EntityTransient(World w) {
		super(w);		
	}
	
	public void update(float deltaT){
		
		if(world.isServer && getCanDespawn()){
			//Despawning... 
			float dist = 0;
			Player p = DangerZone.server.findNearestPlayer(this);
			if(p == null){
				this.deadflag = true;
			}else{
				dist = Utils.getDistanceBetweenEntities(this, p);
				if(dist > DangerZone.entityupdatedist){
					this.deadflag = true;
				}
				if(world.rand.nextInt(500) == 0 && dist > DangerZone.entityupdatedist/2){
					this.deadflag = true;
				}
			}

		}
		super.update(deltaT);
	}
	
	//only during the day where it's light
	public boolean getCanSpawnHereNow(World w, int dimension, int x, int y, int z){
		if(daytimecheck){
			if(!w.isDaytime())return false;
			if(getLightAtLocation(w, dimension, x, y, z) < 0.50f)return false;
		}
		if(nighttimecheck){
			if(w.isDaytime())return false;
			//System.out.printf("light = %f\n", getLightAtLocation(w, dimension, x, y, z));
			if(getLightAtLocation(w, dimension, x, y, z) > 0.50f)return false;
		}
		return true;
	}
	
}

==> dangerzone.0.8.buildkit.zip: src/dangerzone/entities/EntityTransient.java <==
package dangerzone.entities;
import dangerzone.DangerZone;
import dangerzone.Player;
import dangerzone.Utils;
import dangerzone.World;

/*
 * This code is copyright Richard H. Clark, TheyCallMeDanger, OreSpawn, 2015-2020.
 * You may use this code for reference for modding the DangerZone game program,
 * and are perfectly welcome to cut'n'paste portions for your mod as well.
 * DO NOT USE THIS CODE FOR ANY PURPOSE OTHER THAN MODDING FOR THE DANGERZONE GAME.
 * DO NOT REDISTRIBUTE THIS CODE. 
 * 
 * This copyright remains in effect until January 1st, 2021. 
 * At that time, this code becomes public domain.
 * 
 * WARNING: There are bugs. Big bugs. Little bugs. Every size in-between bugs.
 * This code is NOT suitable for use in anything other than this particular game. 
 * NO GUARANTEES of any sort are given, either express or implied, and Richard H. Clark, 
 * TheyCallMeDanger, OreSpawn are not responsible for any damages, direct, indirect, or otherwise. 
 * You should have made backups. It's your own fault for not making them.
 * 
 * NO ATTEMPT AT SECURITY IS MADE. This code is USE AT YOUR OWN RISK.
 * Regardless of what you may think, the reality is, that the moment you 
 * connected your computer to the Internet, Uncle Sam, among many others, hacked it.
 * DO NOT KEEP VALUABLE INFORMATION ON INTERNET-CONNECTED COMPUTERS.
 * Or your phone...
 * 
 */
public class EntityTransient extends EntityLiving {
	
	public boolean daytimecheck = true;
	public boolean nighttimecheck = false;

	public EntityTransient(World w) {
		super(w);		
	}
	
	public void update(float deltaT){
		
		if(world.isServer && getCanDespawn()){
			//Despawning... 
			float dist = 0;
			Player p = DangerZone.server.findNearestPlayer(this);
			if(p == null){
				this.deadflag = true;
			}else{
				dist = Utils.getDistanceBetweenEntities(this, p);
				if(dist > DangerZone.entityupdatedist){
					this.deadflag = true;
				}else if(dist > DangerZone.entityupdatedist/2){
					if(world.rand.nextInt(500) == 0){
						this.deadflag = true;
					}
				}else if(dist > DangerZone.entityupdatedist/4){
					if(world.rand.nextInt(1000) == 0){
						this.deadflag = true;
					}
				}else if(dist > DangerZone.entityupdatedist/8){
					if(world.rand.nextInt(2000) == 0){
						this.deadflag = true;
					}
				}
			}
		}
		super.update(deltaT);
	}
	
	//only during the day where it's light
	public boolean getCanSpawnHereNow(World w, int dimension, int x, int y, int z){
		if(daytimecheck){
			if(!w.isDaytime())return false;
			if(getLightAtLocation(w, dimension, x, y, z) < 0.50f)return false;
		}
		if(nighttimecheck){
			if(w.isDaytime())return false;
			//System.out.printf("light = %f\n", getLightAtLocation(w, dimension, x, y, z));
			if(getLightAtLocation(w, dimension, x, y, z) > 0.50f)return false;
		}
		return true;
	}
	
}
